# PydaConf CLI Guide

PydaConf includes a Command-Line Interface (CLI) to help manage encrypted secrets easily. The CLI allows you to generate encryption keys and securely encrypt/decrypt secrets for use in your configurations.

## Installation

Ensure you have installed PydaConf with CLI support:

```sh
pip install pydaconf[cli]
```

## Using the CLI

The PydaConf CLI is based on `typer` and can be accessed via the `pydaconf` command.

```sh
pydaconf --help
```
